summaryrefslogtreecommitdiff
path: root/src/modlistview.h
diff options
context:
space:
mode:
authorMikaël Capelle <capelle.mikael@gmail.com>2021-01-07 20:11:26 +0100
committerMikaël Capelle <capelle.mikael@gmail.com>2021-01-10 10:27:30 +0100
commitf919e0917344d7396f03423ef4fcd4d41fe37b07 (patch)
tree3cf695b5ce9d77da121a8088a67272654d689921 /src/modlistview.h
parent5765439c7cff4e314a0c5732432bdb7b20e91efd (diff)
Show conflicts and highligth plugins from collapsed separators.
Diffstat (limited to 'src/modlistview.h')
-rw-r--r--src/modlistview.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/src/modlistview.h b/src/modlistview.h
index 08ecd935..53be08c5 100644
--- a/src/modlistview.h
+++ b/src/modlistview.h
@@ -23,6 +23,7 @@ class MainWindow;
class Profile;
class ModListByPriorityProxy;
class ModListViewActions;
+class PluginListView;
class ModListView : public QTreeView
{
@@ -183,15 +184,14 @@ private:
void onModInstalled(const QString& modName);
void onModFilterActive(bool filterActive);
- // overwrite markers
+ // clear overwrite markers (without repainting)
+ //
void clearOverwriteMarkers();
- void setOverwriteMarkers(const std::set<unsigned int>& overwrite, const std::set<unsigned int>& overwritten);
- void setArchiveOverwriteMarkers(const std::set<unsigned int>& overwrite, const std::set<unsigned int>& overwritten);
- void setArchiveLooseOverwriteMarkers(const std::set<unsigned int>& overwrite, const std::set<unsigned int>& overwritten);
- // set overwrite markers from the mod and repaint (if mod is nullptr, clear overwrite and repaint)
+ // set overwrite markers from the mod in the given list and repaint (if the list
+ // is empty, clear overwrite and repaint)
//
- void setOverwriteMarkers(ModInfo::Ptr mod);
+ void setOverwriteMarkers(const QModelIndexList& indexes);
// retrieve the marker color for the given index
//
@@ -251,6 +251,9 @@ private:
QLabel* currentCategory;
QPushButton* clearFilters;
QComboBox* filterSeparators;
+
+ // the plugin list (for highligths)
+ PluginListView* pluginList;
};
OrganizerCore* m_core;